Container
=================================

.. currentmodule:: enaml.widgets.container

.. autoclass:: Container


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_container.QtContainer
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_container.QtContainer

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_container.WXContainer
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_container.WXContainer
